#!/bin/csh -f
#Tag 0x006A0010
#############################################################################
#
# This is the shell script used to launch an IBM-ANSI text display
#
# Usage:
#	acad_ansi.sh 
#
#############################################################################
#
#############################################################################
#
# Start up a text window, then launch AutoCAD with the arguments (if any)
#
# NOTE: The IBM-ANSI Text Window geometry, etc. is set here
#----------------------------------------------------------------------------
# Change: -fn FontNN to change the font and size
# Change: -geometry ColsxRows+17-17 to change the size of the window
# Change: -geometry 80x25+XX-YY to change the lower left corner of the window
# Change: -fg color to change the window text color 
# Change: -bg to change the window background color 
# Change: -cursorbg to change the cursor color 
# Change: -sl nnn to change the number of lines saved in the text window
# Change: -title 'abc' to change the Text Window Title
#
# You should not need to change any of the other options.
#
#############################################################################
#
if ($#argv > 0) then
	setenv _ICONNAME `basename $argv[1]`
else
	setenv _ICONNAME "IBM-ANSI"
endif
setenv _WSH	"/usr/bin/X11/xterm"
setenv _FONT	"-fn vga"
setenv _GEOM	"-geometry 80x25+0-0"
setenv _COLOR	"-bg black -fg white -ms red -cr white"
setenv _SCROLL  "+sb -si -sl 0"
setenv _TITLE	"-title Acad_ANSI_Window -name $_ICONNAME"
setenv _OPTIONS	"+aw +ls +rw -s -sf +vb"
setenv _ACAD	"-e acad_dual"
#
if ($#argv > 1) then
	#-------------------------------------------------------#
	# Start AutoCAD with an initial drawing and script file #
	#-------------------------------------------------------#
	$_WSH $_FONT $_GEOM $_COLOR $_SCROLL $_TITLE $_OPTIONS $_ACAD $argv[1] $argv[2]
else if ($#argv > 0) then
	#--------------------------------------------#
	# Start AutoCAD with an initial drawing file #
	#--------------------------------------------#
	$_WSH $_FONT $_GEOM $_COLOR $_SCROLL $_TITLE $_OPTIONS $_ACAD $argv[1]
else
	#---------------#
	# Start AutoCAD #
	#---------------#
	$_WSH $_FONT $_GEOM $_COLOR $_SCROLL $_TITLE $_OPTIONS $_ACAD
endif
