###################################################################
#	This file is example.login
#
#	It is set up as a working example of a IRIX environment
#	for the AutoCAD user, especially one familiar with MS-DOS
#	It will provide a DOS-like '$PROMPT $P$G' command line.
#
#	It also sets up all the necessary environment variables
#	to allow AutoCAD to run under IRIX.
#
#	The commands in this file are executed when a csh user first
#	logs in.  This file is processed after .cshrc.
#
#	To install this file simply copy it over .login in your
#	home directory, saving the old file for reference:
#		mv $HOME/.login $HOME/.login.old
#		cp ./example.login $HOME/.login
#
#	The MS-DOS command aliases are in a related file, 
#	example.alias in your home directory.  You MUST install a 
#	copy of of this file as .alias if you are using this 
#	.login file.  To do so, follow the instructions in 
#	example.alias.
#
#	These changes will take affect the next time you login.
#
#  	NOTE!!!
#
#	When you rename this file .login, it will not be visible 
#	in your WorkSpace directory views.  To see whether or not 
#	it is really there, enter the following commands into a 
#	shell window:
#		cd
#		ls -a
#    	The "-a" option to the "ls" command will show all files in 
#	a directory including those that begin with a "."
#
###################################################################
#
###################################################################
# Set the interrupt character to Ctrl-c and do clean backspacing.
###################################################################
if (-t 0) then
	stty intr '^C' echoe 
endif
#
###################################################################
# Set the TERM environment variable
###################################################################
eval `tset -s -Q`
#
###################################################################
# Set the default X server.
###################################################################
if ($?DISPLAY == 0) then
	if ($?REMOTEHOST) then
		setenv DISPLAY ${REMOTEHOST}:0
	else
		setenv DISPLAY :0
	endif
endif
#
###################################################################
# About path/PATH:
# The order is important to not confuse /usr/bsd/rsh and /bin/rsh.
# Seting 'path' also sets PATH in the environment for csh users.
# The reverse is not true!
# Dot should be last.  This helps to keep a trojan horse ls or 
# the like program from being found first.  Superuser should not 
# have '.' in his path.
###################################################################
set ignoreeof noglob
set path = ($path /usr/sbin /usr/bsd /bin /etc /usr/bin \
	    /usr/bin/X11 /usr/local/bin /usr/etc /usr/demos/bin \
	    $HOME/bin $ACADPATH .)
#*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$*$*$*$*$*$*$
#*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$*$*$*$*$*$*$
#	NOTE FOR AUTOCAD USER'S
#	Just change ACADPATH in ~/.cshrc to point to AutoCAD.
#*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$*$*$*$*$*$*$
#*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$**$*$*$*$*$*$*$*$*$*$*$*$*$*$*$*$
unset noglob
umask 000
#
###################################################################
# save tty state in a file where wsh can find it
###################################################################
if ((! -f $HOME/.wshttymode) && (-t 0)) then
	stty -g > $HOME/.wshttymode
endif
#
setenv SHELL	/bin/csh
#
###################################################################
# Many programs use mktemp, mkstemp (3C) to generate the names of
# scratch and tmp files.  This environment variable points to
# a user defined scratch area.  On most systems /usr/tmp has more
# room than /tmp. Examples are the c compiler but not vi.
###################################################################
setenv TMPDIR	/usr/tmp
#
###################################################################
# users with larger multi processor systems will want 
# to comment this out to take full advantage of smake.
# pmake is a link to smake which is used by most
# of the 4Dgift Makefiles.
###################################################################
setenv PMAKE  ' -J 2 '
#
###################################################################
# vi and ex are the same program.  See both ex and vi man pages.
# This sets some vi modes in a useful way.
# See also the use of .exrc files in the home directory.
# Avoid using both .exrc and environment variables 
# at the same time because it is such a pain to debug.
###################################################################
setenv EXINIT 'set ai sm sw=4 report=2'
#
########################################################################
# This is ugly because it so dependant on a single display device 'wsh'.
# Still lots of people like it.  Should look at 'tput' for the escapes.
########################################################################
if ($TERM == "iris-ansi"  || $TERM == "iris-ansi-net") then
    alias setp 'set hwd=$cwd:h; set prompt = "[1m< \! [0m`hostname`[1m /$hwd:t/$cwd:t> [0m"'
    if ($?CONSOLE) then
        alias cd 'cd \!*; setp; ls -FC'
    else
        setenv host `hostname`
        alias setitle 'echo -n "\033P1.y"${host}:$cwd"\033\\"'
        setitle
        alias cd 'cd \!*; setp; setitle; ls -FC'
    endif
    setp
else 
        alias setp 'set hwd=$cwd:h; set prompt = "<\! `hostname` /$hwd:t/$cwd:t> "'
        alias cd 'cd \!*; setp; ls -FC'
	setp
endif
#
if ($TERM == "xterm") then
     alias setp 'set hwd=$cwd:h; set prompt = "< \! `hostname` /$hwd:t/$cwd:t> "'
     setenv host `hostname`
     alias setitle 'echo -n "\033P1.y"${host}:$cwd"\033\\"'
     setitle
     alias cd 'cd \!*; setp; setitle; ls -FC'
     setp
endif
#
###################################################################
#	Initialize the Schemes support
###################################################################
if (-e ~/.Xdefaults) then
	/usr/bin/X11/xrdb -merge ~/.Xdefaults
endif
#
###################################################################
#	Include the MS-DOS command aliases
###################################################################
if (-e ~/.alias) then
	source ~/.alias
endif
#
